@@ -1,11 +1,8 @@
 /* definition of standard geoids */
-#ifndef lint
-static const char SCCSID[]="@(#)pj_ellps.c	4.6	95/08/25	GIE	REL";
-#endif
 #define PJ_ELLPS__
 #include "projects.h"
 
-C_NAMESPACE struct PJ_ELLPS
+C_NAMESPACE_VAR struct PJ_ELLPS
 pj_ellps[] = {
 "MERIT",	"a=6378137.0", "rf=298.257", "MERIT 1983",
 "SGS85",	"a=6378136.0", "rf=298.257",  "Soviet Geodetic System 85",
@@ -22,6 +19,7 @@ pj_ellps[] = {
 "bess_nam",	"a=6377483.865", "rf=299.1528128", "Bessel 1841 (Namibia)",
 "clrk66",	"a=6378206.4", "b=6356583.8", "Clarke 1866",
 "clrk80",	"a=6378249.145", "rf=293.4663", "Clarke 1880 mod.",
+"clrk80ign","a=6378249.2", "rf=293.4660212936269", "Clarke 1880 (IGN).",
 "CPM",  	"a=6375738.7", "rf=334.29", "Comm. des Poids et Mesures 1799",
 "delmbr",	"a=6376428.",  "rf=311.5", "Delambre 1810 (Belgium)",
 "engelis",	"a=6378136.05", "rf=298.2566", "Engelis 1985",
